import os
import fitz

from easytrans.file_to_pdf import DocToPdf
from easytrans.constant import FAILURE_STATUS, SUCCESS_STATUS, PDF_FORMAT
from easytrans.utils import FileUtil


class DocToPng(object):

    @staticmethod
    def single_doc_to_png(doc_path, libreoffice_version=7.0, img_dir=None, img_name=None, zoom_x=8, zoom_y=8,
                          rotation_angle=0):
        status, result = DocToPdf.single_doc_to_pdf(doc_path, pdf_dir="/tmp/", pdf_name=None,
                                                    libreoffice_version=libreoffice_version)
        if status == FAILURE_STATUS:
            return FAILURE_STATUS, result

        return PdfToPng.single_pdf_to_img(result, img_dir, img_name, zoom_x, zoom_y, rotation_angle)

    @staticmethod
    def multiple_doc_to_png_by_file_dir(doc_dir, libreoffice_version=7.0, img_dir=None, zoom_x=8, zoom_y=8,
                                        rotation_angle=0):
        try:
            status, result = DocToPdf.multiple_doc_to_pdf_by_file_dir(doc_dir, pdf_dir="/tmp/",
                                                                      libreoffice_version=libreoffice_version)

            if status != SUCCESS_STATUS:
                return status, result

            return PdfToPng.multiple_pdf_to_img_by_file_list(result, img_dir, zoom_x, zoom_y, rotation_angle)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

    @staticmethod
    def multiple_doc_to_png_by_file_list(doc_path_list=[], libreoffice_version=7.0, img_dir=None, zoom_x=8, zoom_y=8,
                                         rotation_angle=0):
        try:
            status, result = DocToPdf.multiple_doc_to_pdf_by_file_list(doc_path_list, pdf_dir="/tmp/",
                                                                       libreoffice_version=libreoffice_version)

            if status != SUCCESS_STATUS:
                return status, result

            return PdfToPng.multiple_pdf_to_img_by_file_list(result, img_dir, zoom_x, zoom_y, rotation_angle)

        except Exception as e:
            return FAILURE_STATUS, repr(e)


class PdfToPng(object):

    @staticmethod
    def single_pdf_to_img(pdf_path, img_dir=None, img_name=None, zoom_x=8, zoom_y=8, rotation_angle=0):
        try:

            if not os.path.isfile(pdf_path) or not os.path.splitext(pdf_path)[1] in PDF_FORMAT:
                return FAILURE_STATUS, "file format error!"

            pdf = fitz.open(pdf_path)

            if not img_name:
                img_name = FileUtil.get_file_name_by_path(pdf_path)

            if not img_dir:
                img_dir = os.path.dirname(pdf_path)

            img_list = []
            pg_count = pdf.pageCount

            for pg in range(0, pg_count):
                page = pdf[pg]
                trans = fitz.Matrix(zoom_x, zoom_y).preRotate(rotation_angle)
                pm = page.getPixmap(matrix=trans, alpha=False)
                if pg_count == 1:
                    img_path = os.path.join(img_dir, "{0}.png".format(img_name))
                else:
                    img_path = os.path.join(img_dir, "{0}{1}.png".format(img_name, str(pg)))
                pm.writePNG(img_path)
                img_list.append(img_path)

            pdf.close()

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return SUCCESS_STATUS, img_list

    @staticmethod
    def multiple_pdf_to_img_by_file_list(pdf_path_list, img_dir=None, zoom_x=8, zoom_y=8, rotation_angle=0):
        try:

            if not isinstance(pdf_path_list, list) or not len(pdf_path_list) > 0:
                return FAILURE_STATUS, "file list is none!"

            img_list = []
            for pdf_path in pdf_path_list:
                status, result = PdfToPng.single_pdf_to_img(pdf_path, img_dir, None, zoom_x, zoom_y, rotation_angle)
                if status == FAILURE_STATUS:
                    return status, result
                else:
                    img_list.append(result)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return SUCCESS_STATUS, img_list

    @staticmethod
    def multiple_pdf_to_img_by_file_dir(pdf_dir, img_dir=None, zoom_x=8, zoom_y=8, rotation_angle=0):
        try:
            if not isinstance(pdf_dir, str) or not os.path.isdir(pdf_dir):
                return FAILURE_STATUS, "'{}' is not a directory!".format(pdf_dir)

            file_list = FileUtil.get_dir_file_path_list(pdf_dir, suffix=PDF_FORMAT)

            return PdfToPng.multiple_pdf_to_img_by_file_list(file_list, img_dir, zoom_x, zoom_y, rotation_angle)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

    @staticmethod
    def cut_pdf_to_img_by_position(pdf_path, img_dir=None, img_name=None, zoom_x=8, zoom_y=8, rect_tl=0, rect_bl=0,
                                   rotation_angle=0):

        try:
            if not os.path.isfile(pdf_path) or not os.path.splitext(pdf_path)[1] in PDF_FORMAT:
                return FAILURE_STATUS, "file format error!"

            pdf = fitz.open(pdf_path)

            if not img_name:
                img_name = FileUtil.get_file_name_by_path(pdf_path)

            if not img_dir:
                img_dir = os.path.dirname(pdf_path)

            if not os.path.exists(img_dir):
                os.makedirs(img_dir)

            img_list = []
            pg_count = pdf.pageCount
            for pg in range(pg_count):
                page = pdf[pg]

                # 每个尺寸的缩放系数为1.3，这将为我们生成分辨率提高2.6的图像
                # 此处若是不做设置，默认图片大小为：792X612, dpi=72
                mat = fitz.Matrix(zoom_x, zoom_y).preRotate(rotation_angle)
                # 页面大小
                rect = page.rect
                # 矩形区域
                # mp = rect.tl + (rect.bl - (0, 75 / zoom_x))
                mp = rect_tl + rect_bl
                # 想要截取的区域
                clip = fitz.Rect(mp, rect.br)
                # 将页面转换为图像
                pix = page.getPixmap(matrix=mat, alpha=False, clip=clip)

                if pg_count == 1:
                    img_path = os.path.join(img_dir, "{0}.png".format(img_name))
                else:
                    img_path = os.path.join(img_dir, "{0}{1}.png".format(img_name, str(pg)))

                pix.writePNG(img_path)
                img_list.append(img_path)

            pdf.close()

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return SUCCESS_STATUS, img_list



import os
from docx import Document
from os.path import exists

from easytrans.constant import FAILURE_STATUS, SUCCESS_STATUS, TXT_FORMAT
from easytrans.utils import FileUtil


class TxtToDoc(object):

    @staticmethod
    def single_txt_to_doc(txt_path, doc_name=None, doc_dir=None):
        if not os.path.isfile(txt_path) or not os.path.splitext(txt_path)[1] in TXT_FORMAT:
            return FAILURE_STATUS, "file format error!"

        status, result = TxtToDoc.txt_transfer_doc([txt_path], [doc_name], doc_dir)
        if status == SUCCESS_STATUS and isinstance(result, list) and len(result) > 0:
            return status, result[0]
        else:
            return status, result

    @staticmethod
    def multiple_txt_to_doc_by_file_dir(txt_dir, doc_dir=None, doc_name_list=None):
        try:

            if not isinstance(txt_dir, str) or not os.path.isdir(txt_dir):
                return FAILURE_STATUS, "'{}' is not a directory!".format(txt_dir)

            file_list = FileUtil.get_dir_file_path_list(txt_dir, suffix=TXT_FORMAT)
            status, result = TxtToDoc.multiple_txt_to_doc_by_file_list(file_list, doc_name_list, doc_dir)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return status, result

    @staticmethod
    def multiple_txt_to_doc_by_file_list(txt_path_list=[], doc_name_list=None, doc_dir=None):
        try:
            if not isinstance(txt_path_list, list) or not len(txt_path_list) > 0:
                return FAILURE_STATUS, "file list is none!"

            return TxtToDoc.txt_transfer_doc(txt_path_list, doc_name_list, doc_dir)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

    @staticmethod
    def txt_transfer_doc(txt_path_list=[], doc_name_list=None, doc_dir=None):
        if not isinstance(txt_path_list, list):
            return FAILURE_STATUS, "'{0}' is not a file list!".format(txt_path_list)

        if doc_name_list and (not isinstance(doc_name_list, list) or len(doc_name_list) < len(txt_path_list)):
            return FAILURE_STATUS, "'{0}' is not matched with file list!".format(doc_name_list)

        doc_list = []
        index = 0

        try:
            for fl in txt_path_list:
                if doc_name_list:
                    doc_name = doc_name_list[index]
                    index = index + 1
                else:
                    doc_name = None

                if not os.path.isfile(fl) or not os.path.splitext(fl)[1] in TXT_FORMAT:
                    continue

                if not doc_name:
                    doc_name = "".join(FileUtil.get_file_name_by_path(fl), ".docx")
                else:
                    doc_name = "".join(doc_name, ".docx")

                if not doc_dir:
                    doc_dir = os.path.dirname(fl)

                with open(fl) as txt_obj:
                    title = txt_obj.readline()
                    txt = txt_obj.read()

                if exists(doc_name):
                    doc = Document(doc_name)
                else:
                    doc = Document()

                doc.add_heading(title)
                doc.add_paragraph(txt)
                save_path = os.path.join(doc_dir, doc_name)
                doc.save(save_path)
                doc_list.append(save_path)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return SUCCESS_STATUS, doc_list



import os
from PIL import Image
import fitz

from easytrans.constant import FAILURE_STATUS, SUCCESS_STATUS, IMAGE_FORMAT
from easytrans.utils import FileUtil


class ImagesToLongImage(object):

    @staticmethod
    def to_long_image_by_file_list(image_path_list, save_name=None, save_dir=None, del_origin_img=False,
                                   background_color=None):

        try:
            if not isinstance(image_path_list, list) or not len(image_path_list) > 0:
                return FAILURE_STATUS, "file list is none!"

            if not save_dir:
                save_dir = os.path.dirname(image_path_list[0])

            if not save_name:
                save_name = FileUtil.generate_file_name()

            save_path = os.path.join(save_dir, "{0}.png".format(save_name))

            image_list = [Image.open(img) for img in image_path_list]

            width = 0
            height = 0
            for img in image_list:
                # 单幅图像尺⼨
                w, h = img.size
                height += h
                # 取最⼤的宽度作为拼接图的宽度
                width = max(width, w)

            # 创建空⽩⻓图
            # background_color: 0xffffff (white color)
            if background_color:
                result = Image.new(image_list[0].mode, (width, height), background_color)
            else:
                result = Image.new(image_list[0].mode, (width, height))

            # 拼接图⽚
            height = 0
            for img in image_list:
                w, h = img.size
                # 图⽚⽔平居中
                result.paste(img, box=(round(width / 2 - w / 2), height))
                height += h

            result.save(save_path)

            if del_origin_img:
                FileUtil.delete_file_list(image_path_list)

            return SUCCESS_STATUS, save_path

        except Exception as e:
            return FAILURE_STATUS, repr(e)

    @staticmethod
    def to_long_image_by_file_dir(image_dir, save_name=None, save_dir=None, del_origin_img=False,
                                  background_color=None):

        try:

            if not isinstance(image_dir, str) or not os.path.isdir(image_dir):
                return FAILURE_STATUS, "'{}' is not a directory!".format(image_dir)

            image_path_list = FileUtil.get_dir_file_path_list(image_dir, suffix=IMAGE_FORMAT)
            return ImagesToLongImage.to_long_image_by_file_list(image_path_list, save_name, save_dir, del_origin_img,
                                                                background_color)

        except Exception as e:
            return FAILURE_STATUS, repr(e)


class JpgToPng(object):
    pass


class ImageToPsd(object):
    @staticmethod
    def single_img_to_psd(img_path, psd_dir=None, psd_name=None):
        try:
            if not os.path.isfile(img_path) or not os.path.splitext(img_path)[1] in IMAGE_FORMAT:
                return FAILURE_STATUS, "file format error!"

            if not psd_dir:
                psd_dir = os.path.dirname(img_path)

            if not psd_name:
                psd_name = FileUtil.generate_file_name()

            psd_path = os.path.join(psd_dir, "{0}.psd".format(psd_name))
            pix = fitz.Pixmap(img_path)
            pix.writeImage(psd_path)

            return SUCCESS_STATUS, psd_path

        except Exception as e:
            return FAILURE_STATUS, repr(e)


class ImageToJpg(object):
    @staticmethod
    def single_img_to_jpg(img_path, jpg_dir=None, jpg_name=None):
        try:
            if not os.path.isfile(img_path) or not os.path.splitext(img_path)[1] in IMAGE_FORMAT:
                return FAILURE_STATUS, "file format error!"

            if not jpg_dir:
                jpg_dir = os.path.dirname(img_path)

            if not jpg_name:
                jpg_name = FileUtil.generate_file_name()

            jpg_path = os.path.join(jpg_dir, "{0}.jpg".format(jpg_name))
            pix = fitz.Pixmap(img_path)
            img = Image.frombytes("RGB", [pix.width, pix.height], pix.samples)
            img.save(jpg_path, "JPEG")

            return SUCCESS_STATUS, jpg_path

        except Exception as e:
            return FAILURE_STATUS, repr(e)



import os
import random
import re
import shutil
import time
import zipfile


class FileUtil(object):

    @staticmethod
    def generate_file_path(file_dir, file_name=None, empty_dir=False, suffix=None):

        if os.path.exists(file_dir) and empty_dir:
            shutil.rmtree(file_dir)

        if not os.path.exists(file_dir):
            os.makedirs(file_dir)

        if not file_name:
            file_name = FileUtil.generate_file_name(suffix)

        file_path = os.path.join(file_dir, file_name)

        return file_path

    @staticmethod
    def generate_file_name(suffix=None):
        file_name = time.strftime('%Y-%m-%d-%H-%M-%S') + '-' + str(time.time()).split(".")[0] + str(
            random.randrange(999999))
        if suffix:
            file_name = "{0}.{1}".format(file_name, suffix)

        return file_name

    @staticmethod
    def get_dir_file_path_list(dir, depth=1, suffix="all"):
        if not isinstance(dir, str) or not os.path.isdir(dir):
            return []

        file_list = []
        for file in os.listdir(dir):
            file = os.path.join(dir, file)

            if os.path.isdir(file) and depth > 1:
                file_list.extend(FileUtil.get_dir_file_path_list(file, depth - 1, suffix))
            elif os.path.isdir(file):
                continue
            elif not suffix == "all" and not os.path.splitext(file)[1] in suffix:
                continue
            else:
                file_list.append(file)

        return file_list

    @staticmethod
    def get_file_name_by_path(file_path):
        file_name = os.path.split(file_path)[1]
        file_name = os.path.splitext(file_name)[0]
        return file_name

    @staticmethod
    def zip_files(file_dir, zip_dir=None, zip_name=None):
        if not zip_name:
            zip_name = FileUtil.generate_file_name()

        if not zip_dir:
            zip_dir = os.path.abspath(os.path.join(file_dir, os.path.pardir))

        zip_path = os.path.join(zip_dir, "{0}.zip".format(zip_name))

        zip = zipfile.ZipFile(zip_path, 'w', zipfile.ZIP_DEFLATED)

        for d_path, d_names, file_names in os.walk(file_dir):
            f_path = d_path.replace(file_dir, '')
            f_path = f_path and f_path + os.sep or ''
            for filename in file_names:
                zip.write(os.path.join(d_path, filename), f_path + filename)

        zip.close()

        return zip_path

    @staticmethod
    def delete_file(path):
        if os.path.isfile(path):
            os.remove(path)
            # os.unlink(path)
            return True
        else:
            return False

    @staticmethod
    def delete_file_list(path_list):
        result = [FileUtil.delete_file(path) for path in path_list if os.path.isfile(path)]
        return result

    @staticmethod
    def delete_dir(dir):
        if os.path.exists(dir):
            shutil.rmtree(dir)
            return True
        else:
            return False

    @staticmethod
    def file_rename(origin_file_path, target_file_name):
        if not os.path.isfile(origin_file_path):
            return None

        file_suffix = os.path.splitext(origin_file_path)[1]
        target_file_path = os.path.join(os.path.dirname(origin_file_path),
                                        "{0}{1}".format(target_file_name, file_suffix))
        os.rename(origin_file_path, target_file_path)

        return target_file_path

    @staticmethod
    def format_name(file_name):
        result = []
        for s in str(file_name):
            if StringUtil.is_not_chinese(s) or re.match("^[0-9a-zA-Z_-]+$", s):
                result.append(s)
        return "".join(result)

    @staticmethod
    def file_info():
        pass


class StringUtil(object):

    @staticmethod
    def is_not_chinese(input):
        code = str(input).encode("utf-8").decode("utf-8")
        if u'\u4e00' <= code <= u'\u9fff':
            return True
        else:
            return False

    @staticmethod
    def is_not_number(input):
        return str(input).isdigit()

    @staticmethod
    def is_not_alpha(input):
        return str(input).isalpha()

    @staticmethod
    def is_not_underline(input):
        return "-" == input

    @staticmethod
    def is_not_underscore(input):
        return "_" == input


class DateUtil(object):
    pass



import os

from easytrans.constant import FAILURE_STATUS, SUCCESS_STATUS, DOC_FORMAT
from easytrans.utils import FileUtil


class DocToPdf(object):

    @staticmethod
    def single_doc_to_pdf(doc_path, pdf_dir=None, pdf_name=None, libreoffice_version=7.0):

        try:

            if not os.path.isfile(doc_path) or not os.path.splitext(doc_path)[1] in DOC_FORMAT:
                return FAILURE_STATUS, "file format error!"

            if libreoffice_version:
                libreoffice = "libreoffice{0}".format(libreoffice_version)
            else:
                libreoffice = "libreoffice"

            if pdf_dir:
                cmd = "{0} --headless --convert-to pdf --outdir {1} {2}".format(libreoffice, pdf_dir, doc_path)
            else:
                cmd = "{0} --headless --convert-to pdf {1}".format(libreoffice, doc_path)
                pdf_dir = os.path.dirname(doc_path)

            res = os.system(cmd)
            if res != 0:
                return FAILURE_STATUS, "file convert failed!"

            origin_file_name = FileUtil.get_file_name_by_path(doc_path)
            origin_file_path = os.path.join(pdf_dir, "{0}.pdf".format(origin_file_name))
            if pdf_name:
                destin_file_path = os.path.join(pdf_dir, "{0}.pdf".format(pdf_name))
                os.rename(origin_file_path, destin_file_path)
                file_path = destin_file_path
            else:
                file_path = origin_file_path

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return SUCCESS_STATUS, file_path

    @staticmethod
    def multiple_doc_to_pdf_by_file_dir(doc_dir, pdf_dir=None, libreoffice_version=7.0):
        try:

            if not isinstance(doc_dir, str) or not os.path.isdir(doc_dir):
                return FAILURE_STATUS, "'{0}' is not a directory!".format(doc_dir)

            file_list = FileUtil.get_dir_file_path_list(doc_dir, suffix=DOC_FORMAT)
            status, result = DocToPdf.multiple_doc_to_pdf_by_file_list(file_list, pdf_dir, libreoffice_version)

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return status, result

    @staticmethod
    def multiple_doc_to_pdf_by_file_list(doc_path_list, pdf_dir=None, libreoffice_version=7.0):
        pdf_path_list = []
        try:
            if not isinstance(doc_path_list, list) or not len(doc_path_list) > 0:
                return FAILURE_STATUS, "file list is none!"

            for doc_path in doc_path_list:
                status, result = DocToPdf.single_doc_to_pdf(doc_path, pdf_dir, None, libreoffice_version)
                if status == SUCCESS_STATUS:
                    pdf_path_list.append(result)
                else:
                    return status, result

        except Exception as e:
            return FAILURE_STATUS, repr(e)

        else:
            return SUCCESS_STATUS, pdf_path_list


class TxtToPdf(object):

    @staticmethod
    def single_txt_to_pdf(txt_path, pdf_dir=None, pdf_name=None):
        pass

    @staticmethod
    def txt_transfer_pdf(file_list=[], pdf_name_list=None, libreoffice_version=7.0):
        pass



SUCCESS_STATUS = 0
FAILURE_STATUS = 1

TXT_FORMAT = [".txt", ".rtf"]

PDF_FORMAT = [".pdf"]

DOC_FORMAT = [".doc", ".docx"]
XLS_FORMAT = [".xls", ".xlsx"]

IMAGE_FORMAT = [".jpg", ".webp", ".bmp", ".pcx", ".tif", ".gif", ".jpeg", ".tga", ".exif", ".fpx", ".svg", ".psd",
                ".cdr", ".pcd", ".dxf", ".ufo", ".eps", ".ai", ".png", ".hdri", ".raw", ".wmf", ".flic", ".emf", ".ico",
                ".avif"]



import os

from openpyxl import load_workbook
from docxtpl import DocxTemplate

from easytrans.constant import FAILURE_STATUS, SUCCESS_STATUS, DOC_FORMAT, XLS_FORMAT
from easytrans.utils import FileUtil


class DataExportDoc(object):

    @staticmethod
    def data_to_doc(data, docx_template_path, doc_dir=None, doc_name=None, variable_name="data"):
        try:
            if not data or not docx_template_path:
                return FAILURE_STATUS, "'data' or 'docx_template_path' error!"

            if not os.path.isfile(docx_template_path) or not os.path.splitext(docx_template_path)[1] in DOC_FORMAT:
                return FAILURE_STATUS, "'{0}' file format error!".format(docx_template_path)

            doc_t = DocxTemplate(docx_template_path)
            doc_t.render({variable_name: data})

            if not doc_name:
                doc_name = FileUtil.generate_file_name()

            if not doc_dir:
                doc_dir = os.getcwd()

            if not os.path.exists(doc_dir):
                os.makedirs(doc_dir)

            doc_path = os.path.join(doc_dir, "{0}.docx".format(doc_name))

            doc_t.save(doc_path)

            return SUCCESS_STATUS, doc_path

        except Exception as e:
            return FAILURE_STATUS, repr(e)


class DataExportExcel(object):

    @staticmethod
    def data_to_xls(data_list, xlsx_template_path, start_row=1, start_col=1, xls_dir=None, xls_name=None,
                    sheet_index=0):
        try:
            if not data_list or not xlsx_template_path:
                return FAILURE_STATUS, "'data_list' or 'xlsx_template_path' error!"

            if not os.path.isfile(xlsx_template_path) or not os.path.splitext(xlsx_template_path)[1] in XLS_FORMAT:
                return FAILURE_STATUS, "'{0}' file format error!".format(xlsx_template_path)

            wb = load_workbook(filename=xlsx_template_path)
            names = wb.sheetnames
            ws = wb.get_sheet_by_name(names[sheet_index])

            if not xls_name:
                xls_name = FileUtil.generate_file_name()

            if not xls_dir:
                xls_dir = os.getcwd()

            if not os.path.exists(xls_dir):
                os.makedirs(xls_dir)

            for row in range(len(data_list)):
                for col in range(len(data_list[row])):
                    ws.cell(row=start_row + row, column=start_col + col).value = data_list[row][col]

            xls_path = os.path.join(xls_dir, "{0}.xlsx".format(xls_name))

            wb.save(xls_path)

            return SUCCESS_STATUS, xls_path

        except Exception as e:
            return FAILURE_STATUS, repr(e)


class DataExportTxt(object):
    pass



#!/usr/bin/env python
# coding: utf-8
# author: Frank YCJ
# email: 1320259466@qq.com

import setuptools

with open("easytrans/README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="easytrans",
    version="0.0.7",
    author="Frank YCJ",
    author_email="1320259466@qq.com",
    description="The easytrans makes the file transfer simpler!",
    keywords='file format transfer word doc pdf png jpg txt convert',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/YouAreOnlyOne",
    # packages=setuptools.find_packages(),
    packages=["easytrans"],
    install_requires=["fitz>=0.0.1.dev2", "PyMuPDF>1.0.0", "python-docx>0.5.0", "openpyxl>=3.0.5", "Pillow>=8.0.1"],
    # python_requires=">=2.4",
    license="Apache 2.0 license",
    Platform="OS All",

    project_urls={
        "Bug Tracker": "https://github.com/YouAreOnlyOne/FastFrameJar/issues",
        "Documentation": "https://github.com/YouAreOnlyOne/FastFrameJar",
        "Source Code": "https://github.com/YouAreOnlyOne/FastFrameJar",
    },

    package_data={
        # If any package contains *.txt or *.rst files, include them:
        "easytrans": ["README"],
        "easytrans": ["README.md"],
        "": ["README.md"],
        "easytrans": ["*.md"],
        "easytrans": ["*.docx", "*.doc", "*.xls", "*.xlsx"],
        "easytrans": ["LICENSE"],
    },
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
